From 29f92cbaf6367c4e1b4bedca50bc9d434a3aa842 Mon Sep 17 00:00:00 2001
From: Paul Eggert <eggert@cs.ucla.edu>
Date: Tue, 26 Apr 2016 08:38:36 -0700
Subject: [PATCH] insert-char annotates names only on request

This fixes a major UI efficiency problem with C-x 8 RET (Bug#23377).
Solution suggested by Stefan Monnier in: http://bugs.gnu.org/23377#36
* lisp/international/mule-cmds.el (unicode-name-annotation-style):
New var.
(read-char-by-name): Use it.
---
 lisp/international/mule-cmds.el | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/lisp/international/mule-cmds.el b/lisp/international/mule-cmds.el
index dbf1224..80ac4de 100644
--- a/lisp/international/mule-cmds.el
+++ b/lisp/international/mule-cmds.el
@@ -2978,6 +2978,12 @@ mule--ucs-names-annotation
   (let ((char (assoc name ucs-names)))
     (when char (format " (%c)" (cdr char)))))
 
+(defvar unicode-name-annotation-style nil
+  "Style to use when listing Unicode character names.
+If non-nil, also list the character itself, next to its name.
+The `insert-char' function uses this style when completing
+Unicode names interactively.")
+
 (defun read-char-by-name (prompt)
   "Read a character by its Unicode name or hex number string.
 Display PROMPT and read a string that represents a character by its
@@ -3001,9 +3007,11 @@ read-char-by-name
 	   prompt
 	   (lambda (string pred action)
 	     (if (eq action 'metadata)
-		 '(metadata
-		   (annotation-function . mule--ucs-names-annotation)
-		   (category . unicode-name))
+                 (if unicode-name-annotation-style
+                     '(metadata
+                       (annotation-function . mule--ucs-names-annotation)
+                       (category . unicode-name))
+                   '(metadata (category . unicode-name)))
 	       (complete-with-action action (ucs-names) string pred)))))
 	 (char
 	  (cond
-- 
2.5.5

